@@ -666,7 +666,17 @@ bundle:my_bundle  # items in this bundle
     )
 
     # bw plot node
-    help_plot_node = _("Plot items and their dependencies for the given node")
+    help_plot_node = _(
+        "Plot items and their dependencies for the given node. "
+        "Color guide: "
+        "needs in red, "
+        "after in blue, "
+        "concurrency blockers in purple, "
+        "before in yellow, "
+        "needed_by in orange, "
+        "auto in green, "
+        "triggers in pink"
+    )
     parser_plot_subparsers_node = parser_plot_subparsers.add_parser(
         "node",
         description=help_plot_node,
@@ -689,7 +699,7 @@ bundle:my_bundle  # items in this bundle
         "--no-depends-auto",
         action='store_false',
         dest='depends_auto',
-        help=_("do not show auto-generated dependencies and items"),
+        help=_("do not show auto-generated and trigger dependencies"),
     )
     parser_plot_subparsers_node.add_argument(
         "--no-depends-conc",
@@ -701,13 +711,13 @@ bundle:my_bundle  # items in this bundle
         "--no-depends-regular",
         action='store_false',
         dest='depends_regular',
-        help=_("do not show regular user-defined dependencies"),
+        help=_("do not show after/needs dependencies"),
     )
     parser_plot_subparsers_node.add_argument(
         "--no-depends-reverse",
         action='store_false',
         dest='depends_reverse',
-        help=_("do not show reverse dependencies ('needed_by')"),
+        help=_("do not show before/needed_by dependencies"),
     )
 
     # bw plot groups-for-node
@@ -961,7 +971,7 @@ bundle:my_bundle  # items in this bundle
         "--show-all",
         action='store_true',
         dest='show_all',
-        help=_("show correct items as well as incorrect ones"),
+        help=_("show correct and skipped items as well as incorrect ones"),
     )
     parser_verify.add_argument(
         "-D",
@@ -970,6 +980,22 @@ bundle:my_bundle  # items in this bundle
         dest='show_diff',
         help=_("hide diff for incorrect items"),
     )
+    parser_verify.add_argument(
+        "-o",
+        "--only",
+        default=[],
+        dest='autoonly',
+        help=_("""skip all items not matching any SELECTOR:
+
+file:/my_path     # this specific item
+tag:my_tag        # items with this tag
+bundle:my_bundle  # items in this bundle
+        """),
+        metavar=_("SELECTOR"),
+        nargs='+',
+        type=str,
+    )
+
     bw_verify_p_default = int(environ.get("BW_NODE_WORKERS", "4"))
     parser_verify.add_argument(
         "-p",
@@ -990,6 +1016,21 @@ bundle:my_bundle  # items in this bundle
                "(defaults to {})").format(bw_verify_p_items_default),
         type=int,
     )
+    parser_verify.add_argument(
+        "-s",
+        "--skip",
+        default=[],
+        dest='autoskip',
+        help=_("""skip items matching any SELECTOR:
+
+file:/my_path     # this specific item
+tag:my_tag        # items with this tag
+bundle:my_bundle  # items in this bundle
+        """),
+        metavar=_("SELECTOR"),
+        nargs='+',
+        type=str,
+    )
     parser_verify.add_argument(
         "-S",
         "--no-summary",
