@@ -1,13 +1,13 @@
 from copy import copy
 from sys import exit
 
-from ..exceptions import FaultUnavailable, ItemDependencyLoop
+from ..deps import ItemDependencyLoop
+from ..exceptions import FaultUnavailable
 from ..itemqueue import ItemTestQueue
 from ..metadata import check_for_metadata_conflicts, metadata_to_json
 from ..repo import Repository
 from ..utils.cmdline import count_items, get_target_nodes
 from ..utils.dicts import diff_value, diff_value_text
-from ..utils.plot import explain_item_dependency_loop
 from ..utils.text import bold, green, mark_for_translation as _, red, yellow
 from ..utils.ui import io, QUIT_EVENT
 
@@ -66,10 +66,7 @@ def test_items(nodes, ignore_missing_faults, quiet):
                         x=green("✓"),
                     ))
         if item_queue.items_with_deps and not QUIT_EVENT.is_set():
-            exception = ItemDependencyLoop(item_queue.items_with_deps)
-            for line in explain_item_dependency_loop(exception, node.name):
-                io.stderr(line)
-            exit(1)
+            raise ItemDependencyLoop(item_queue.items_with_deps)
     io.progress_set_total(0)
 
 
@@ -189,22 +186,20 @@ def test_determinism(repo, nodes, iterations_config, iterations_metadata, quiet)
                             current_cdict_keys = set(current_cdict.keys())
                             previous_cdict = previous_item.display_on_create(previous_item.cdict().copy())
                             previous_cdict_keys = set(previous_cdict.keys())
-                            assert current_cdict_keys == previous_cdict_keys, \
-                                "cdict mismatch: " + str(
-                                    current_cdict_keys.symmetric_difference(previous_cdict_keys)
-                                )
                             output = _("{x} {node}  {item} changed:\n").format(
                                 x=red("✘"),
                                 node=bold(node.name),
                                 item=item.id,
                             )
                             diff = "\n"
-                            for key in sorted(current_cdict_keys):
-                                if current_cdict[key] != previous_cdict[key]:
+                            for key in sorted(current_cdict_keys | previous_cdict_keys):
+                                current_value = current_cdict.get(key, "<not present>")
+                                previous_value = previous_cdict.get(key, "<not present>")
+                                if current_value != previous_value:
                                     diff += diff_value(
                                         key,
-                                        current_cdict[key],
-                                        previous_cdict[key],
+                                        current_value,
+                                        previous_value,
                                     ) + "\n"
                             for line in diff.splitlines():
                                 output += "{x} {line}\n".format(
@@ -257,7 +252,7 @@ def test_reactor_provides(repo, nodes, quiet):
     for node in nodes:
         if QUIT_EVENT.is_set():
             break
-        node.metadata.get(tuple())
+        node.metadata.get(())
     else:
         if not quiet:
             io.stdout(_("{x} No reactors violated their declared keys").format(
