@@ -1,28 +1,27 @@
 from . import names
-from .text import mark_for_translation as _, red
+from .text import mark_for_translation as _
 
 
-def explain_item_dependency_loop(exc, node_name):
+def explain_item_dependency_loop(items):
     """
-    Given an ItemDependencyLoop exception and a node name, generates
-    output lines to help users debug the issue.
+    Generates output lines to help users debug the issue.
     """
-    items = remove_items_not_contributing_to_loop(exc.items)
+    items = remove_items_not_contributing_to_loop(items)
+    node_name = items[0].node.name
 
     yield _(
-        "{x} There was a dependency problem on node '{node}'. Look at the debug.svg generated "
+        "There was a dependency problem on node '{node}'. Look at the debug.svg generated "
         "by the following command and try to find a loop:\n\n\n"
         "printf '{cmd}' | dot -Tsvg -odebug.svg\n\n\n"
     ).format(
-        x=red("!"),
         node=node_name,
         cmd="\\n".join(graph_for_items(node_name, items)),
     )
 
     yield _(
-        "{x} Additionally, here is a list of all items involved "
+        "Additionally, here is a list of all items involved "
         "and their remaining dependencies:\n"
-    ).format(x=red("!"))
+    )
     for item in items:
         yield "{}\t{}".format(item.id, ",".join([item.id for item in sorted(item._deps)]))
     yield "\n\n\n"
@@ -59,9 +58,7 @@ def graph_for_items(
                  "style=\"rounded,filled\"]")
     yield "edge [arrowhead=vee]"
 
-    item_ids = []
-    for item in items:
-        item_ids.append(item.id)
+    item_ids = {item.id for item in items}
 
     if cluster:
         # Define which items belong to which bundle
@@ -74,8 +71,6 @@ def graph_for_items(
             bundle_number += 1
             yield "{"
             yield "label = \"{}\"".format(item.bundle.name)
-            if "bundle:{}".format(item.bundle.name) in item_ids:
-                yield "\"bundle:{}\"".format(item.bundle.name)
             for bitem in item.bundle.items:
                 if bitem.id in item_ids:
                     yield "\"{}\"".format(bitem.id)
@@ -85,23 +80,27 @@ def graph_for_items(
     # Define dependencies between items
     for item in items:
         if regular:
-            for dep in item.needs:
-                if dep in item_ids:
-                    yield "\"{}\" -> \"{}\" [color=\"#C24948\",penwidth=2]".format(item.id, dep)
+            for dep in sorted(item._deps_needs):
+                yield "\"{}\" -> \"{}\" [color=\"#C24948\",penwidth=2]".format(item.id, dep.id)
+            for dep in sorted(item._deps_after):
+                yield "\"{}\" -> \"{}\" [color=\"#42AFFF\",penwidth=2]".format(item.id, dep.id)
+
+        if concurrency:
+            for dep in sorted(item._deps_concurrency):
+                yield "\"{}\" -> \"{}\" [color=\"#714D99\",penwidth=2]".format(item.id, dep.id)
+
+        if reverse:
+            for dep in sorted(item._deps_before):
+                yield "\"{}\" -> \"{}\" [color=\"#D1CF52\",penwidth=2]".format(item.id, dep.id)
+            for dep in sorted(item._deps_needed_by):
+                yield "\"{}\" -> \"{}\" [color=\"#D18C57\",penwidth=2]".format(item.id, dep.id)
 
         if auto:
-            for dep in sorted(item._deps):
-                if dep not in items:
-                    continue
-                if dep.id in getattr(item, '_concurrency_deps', []):
-                    if concurrency:
-                        yield "\"{}\" -> \"{}\" [color=\"#714D99\",penwidth=2]".format(item.id, dep)
-                elif dep in item._reverse_deps:
-                    if reverse:
-                        yield "\"{}\" -> \"{}\" [color=\"#D18C57\",penwidth=2]".format(item.id, dep)
-                elif dep.id not in item.needs:
-                    if dep in items:
-                        yield "\"{}\" -> \"{}\" [color=\"#6BB753\",penwidth=2]".format(item.id, dep)
+            for dep in sorted(item._deps_auto):
+                yield "\"{}\" -> \"{}\" [color=\"#6BB753\",penwidth=2]".format(item.id, dep.id)
+
+            for dep in sorted(item._deps_triggers):
+                yield "\"{}\" -> \"{}\" [color=\"#fca7f7\",penwidth=2]".format(item.id, dep.id)
 
     # Global graph title
     yield "fontsize = 28"
